@@ -5,7 +5,7 @@ import warnings
 from beartype.roar import BeartypeDecorHintPepDeprecatedWarning
 from loguru import logger
 
-__version__ = '0.3.0'
+__version__ = '0.9.0'
 __pkg_name__ = 'calcipy'
 
 logger.disable(__pkg_name__)
@@ -15,3 +15,8 @@ logger.disable(__pkg_name__)
 warnings.simplefilter(action='ignore', category=BeartypeDecorHintPepDeprecatedWarning)
 
 # ====== Above is the recommended code from calcipy_template and may be updated on new releases ======
+
+# Load entry point for CLI
+from .cli.main import run  # noqa: E402
+
+__all__ = ('run',)
