@@ -4,14 +4,14 @@ import shutil
 import webbrowser
 from collections import defaultdict
 from pathlib import Path
-from typing import Iterable
+from typing import Iterable, List
 
 from beartype import beartype
 from doit.task import Task
 from loguru import logger
+from sty import fg
 
-from calcipy.file_helpers import if_found_unlink
-
+from ..file_helpers import if_found_unlink
 from .doit_globals import DG, DoitAction, DoitTask
 
 
@@ -26,8 +26,15 @@ def _show_cmd(task: Task) -> str:
         str: describing the sequence of actions
 
     """
-    actions = ''.join(f'\n\t{act}' for act in task.actions)
-    return f'{task.name} > [{actions}\n]\n'
+    def clean_action(action: str) -> str:
+        action = action.replace(f'{DG.meta.path_project.as_posix()}/', '')
+        if 'password' in action:
+            action = action.split('password')[0] + '...password-redacted...'
+        return action  # noqa: R504
+
+    indent = '\n\t'
+    actions = indent.join(map(clean_action, map(str, task.actions)))
+    return f'{task.name} > [{indent}{fg.grey}{actions}{fg.rs}\n]\n'
 
 
 @beartype
@@ -70,6 +77,7 @@ def write_text(path_file: Path, text: str) -> None:
         text: string to write to file
 
     """
+    path_file.parent.mkdir(exist_ok=True, parents=True)
     path_file.write_text(text)  # pragma: no cover
 
 
@@ -97,10 +105,10 @@ def _make_archive(path_dir: Path, archive_format: str = 'zip') -> None:
 
 
 @beartype
-def task_zip_release() -> DoitTask:
+def _zip_release() -> List[DoitAction]:
     """Zip up important information in the releases directory.
 
-    > WARN: paths must be reflected in AppVeyor.yml to be collected
+    > WARN: zip paths must be in the AppVeyor.yml to be collected
 
     Returns:
         DoitTask: doit task
@@ -115,4 +123,15 @@ def task_zip_release() -> DoitTask:
                 (_make_archive, (path_dir,)),
                 (echo, (f'Created: {path_zip}',)),
             ])
-    return debug_task(actions)
+    return actions
+
+
+@beartype
+def task_zip_release() -> DoitTask:
+    """Zip up important information in the releases directory.
+
+    Returns:
+        DoitTask: doit task
+
+    """
+    return debug_task(_zip_release())
