@@ -12,9 +12,9 @@ from doit.tools import Interactive
 from loguru import logger
 from transitions import Machine
 
-from ..file_helpers import _MKDOCS_CONFIG_NAME, _read_yaml_file, read_lines
-from .base import debug_task, open_in_browser
-from .doit_globals import DG, DoitTask
+from ..file_helpers import _MKDOCS_CONFIG_NAME, _read_yaml_file, delete_dir, read_lines, trim_trailing_whitespace
+from .base import debug_task, echo, open_in_browser, write_text
+from .doit_globals import DG, DoitAction, DoitTask
 
 # ----------------------------------------------------------------------------------------------------------------------
 # Manage Changelog
@@ -35,7 +35,7 @@ def _move_cl() -> None:
 
 
 @beartype
-def task_cl_write() -> DoitTask:
+def _write_changelog() -> List[DoitAction]:
     """Write a Changelog file with the raw Git history.
 
     Resources:
@@ -47,14 +47,25 @@ def task_cl_write() -> DoitTask:
     - https://semver.org/
     - https://calver.org/
 
+    Returns:
+        List[DoitAction]: doit actions
+
+    """
+    return [
+        'poetry run cz changelog',
+        (_move_cl, ()),
+    ]
+
+
+@beartype
+def task_cl_write() -> DoitTask:
+    """Auto-generate the changelog based on commit history and tags.
+
     Returns:
         DoitTask: doit task
 
     """
-    return debug_task([
-        'poetry run cz changelog',
-        (_move_cl, ()),
-    ])
+    return debug_task(_write_changelog())
 
 
 @beartype
@@ -66,15 +77,15 @@ def task_cl_bump() -> DoitTask:
 
     """
     return debug_task([
-        Interactive('poetry run cz bump --changelog --annotated-tag'),
-        (_move_cl, ()),
+        *_write_changelog(),
+        Interactive('poetry run cz bump --annotated-tag'),
         'git push origin --tags --no-verify',
     ])
 
 
 @beartype
 def task_cl_bump_pre() -> DoitTask:
-    """Bump with specified pre-release tag.
+    """Bump with specified pre-release tag. Requires a parameter (`-p alpha`, `-p beta`, `-p rc`, etc.).
 
     Example: `doit run cl_bump_pre -p alpha` or `doit run cl_bump_pre -p rc`
 
@@ -83,8 +94,8 @@ def task_cl_bump_pre() -> DoitTask:
 
     """
     task = debug_task([
-        Interactive('poetry run cz bump --changelog --prerelease %(prerelease)s'),
-        (_move_cl, ()),
+        *_write_changelog(),
+        Interactive('poetry run cz bump --prerelease %(prerelease)s'),
         'git push origin --tags --no-verify',
     ])
     task['params'] = [{
@@ -257,13 +268,13 @@ def _format_cov_table(coverage_data: Dict[str, Any]) -> List[str]:
     # Format table for Github Markdown
     df_cov = pd.DataFrame(records)
     df_cov['Coverage'] = df_cov['Coverage'].round(1).astype(str) + '%'
-    lines_table = df_cov.to_markdown(index=False).split('\n')  # Note: requires optional "tabulate"
+    lines_table = df_cov.to_markdown(index=False).split('\n')
     lines_table.extend(['', f"Generated on: {coverage_data['meta']['timestamp']}"])
     return lines_table
 
 
 @beartype
-def _handle_coverage(line: str, path_file: Path) -> List[str]:
+def _handle_coverage(line: str, _path_file: Path) -> List[str]:
     """Read the coverage.json file and write a Markdown table to the README file.
 
     Args:
@@ -303,6 +314,48 @@ def write_autoformatted_md_sections() -> None:
         path_md.write_text('\n'.join(md_lines))
 
 
+# ----------------------------------------------------------------------------------------------------------------------
+# Working with Diagram
+
+
+@beartype
+def _diagram_tasks(pdoc_out_path: Path) -> List[DoitAction]:
+    """Return actions to generate code diagrams in the module documentation directory.
+
+    Note: must be run after `document` because pdocs will delete these files
+
+    PUML support may be coming in a future release: https://github.com/PyCQA/pylint/issues/4498
+
+    Args:
+        pdoc_out_path: path to the top-level pdoc output. Expect subdir with module name
+
+    Returns:
+        List[DoitAction]: actions to generate the
+
+    """
+    diagram_md = """# Code Diagrams
+
+> Auto-generated with `pylint-pyreverse`
+
+## Packages
+
+![./packages.svg](./packages.svg)
+
+[Full Size](./packages.svg)
+
+## Classes
+
+![./classes.svg](./classes.svg)
+
+[Full Size](./classes.svg)
+"""
+    path_diagram = pdoc_out_path / DG.meta.pkg_name / '_code_diagrams.md'
+    return [
+        (write_text, (path_diagram, diagram_md)),
+        Interactive(f'poetry run pyreverse {DG.meta.pkg_name} --output svg --output-directory {path_diagram.parent}'),
+    ]
+
+
 # ----------------------------------------------------------------------------------------------------------------------
 # Main Documentation Tasks
 
@@ -317,6 +370,13 @@ def _ensure_handler_lookup() -> None:
         }
 
 
+@beartype
+def _find_and_trim_trailing_whitespace(doc_dir: Path) -> None:
+    """Find all markdown files and trim any trailing whitespace."""
+    for path_md in doc_dir.rglob('*/md'):
+        trim_trailing_whitespace(path_md)
+
+
 @beartype
 def task_document() -> DoitTask:
     """Build the HTML documentation.
@@ -326,11 +386,15 @@ def task_document() -> DoitTask:
 
     """
     _ensure_handler_lookup()
-    pdoc_out = f'--output_dir {DG.doc.doc_sub_dir.parent}/modules --overwrite'
+    pdoc_out_path = DG.doc.auto_doc_path
+    pdoc_out = f'--output_dir {pdoc_out_path} --overwrite'
     pdoc_template = f'--template_dir {DG.calcipy_dir}/doit_tasks/templates'
     return debug_task([
         (write_autoformatted_md_sections, ()),
+        (delete_dir, (pdoc_out_path,)),
         Interactive(f'poetry run pdocs as_markdown {DG.meta.pkg_name} {pdoc_out} {pdoc_template}'),
+        *_diagram_tasks(pdoc_out_path),
+        (_find_and_trim_trailing_whitespace, (pdoc_out_path,)),
         Interactive(f'poetry run mkdocs build --site-dir {DG.doc.path_out}'),
     ])
 
@@ -359,7 +423,7 @@ def task_open_docs() -> DoitTask:
 
     """
     if _is_mkdocs_local():  # pragma: no cover
-        path_doc_index = DG.doc.path_out / DG.meta.pkg_name / 'index.html'
+        path_doc_index = DG.doc.path_out / 'index.html'
         return debug_task([
             (open_in_browser, (path_doc_index,)),
         ])
@@ -379,6 +443,6 @@ def task_deploy_docs() -> DoitTask:
     """
     if _is_mkdocs_local():  # pragma: no cover
         return debug_task([
-            (NotImplementedError, ('Deploy cannot be used with mkdocs built with local-links',)),
+            (echo, ('ERROR: Not yet configured to deploy documentation without "use_directory_urls"',)),
         ])
     return debug_task([Interactive('poetry run mkdocs gh-deploy')])
